@@ -5,9 +5,9 @@ import json
 import platform
 import warnings
 import yaml
+from contextlib import redirect_stdout
 from enum import Enum
 from io import StringIO
-from contextlib import redirect_stdout
 from typing import Any, Dict, List, Optional, Tuple, Union
 from jsonargparse_tests.base import *
 from jsonargparse.actions import _find_action
@@ -382,6 +382,13 @@ class SignaturesTests(unittest.TestCase):
         self.assertRaises(ParserError, lambda: parser.parse_args([]))
 
 
+    def test_not_required_group(self):
+        parser = ArgumentParser(parse_as_dict=True, error_handler=None)
+        parser.add_subclass_arguments(calendar.Calendar, 'cal', required=False)
+        cfg = parser.parse_args([])
+        self.assertEqual(cfg, {'cal': {}})
+
+
     def test_invalid_type(self):
 
         def func(a1: None):
